#
# spec file for package python-gast
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define srcname gast
Name:           python-gast
# only update when python-pythran is compatible
Version:        0.6.0
Release:        1.3
Summary:        Python AST that abstracts the underlying Python version
License:        BSD-3-Clause
URL:            https://github.com/serge-sans-paille/gast/
Source:         https://github.com/serge-sans-paille/gast/archive/%{version}.tar.gz#/%{srcname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  fdupes
BuildArch:      noarch
%python_subpackages

%description

A generic AST to represent Python2 and Python3's Abstract Syntax Tree(AST).

GAST provides a compatibility layer between the AST of various Python versions,
as produced by ``ast.parse`` from the standard ``ast`` module.

%prep
%autosetup -p1 -n gast-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v tests

%files %{python_files}
%{python_sitelib}/gast
%{python_sitelib}/gast-%{version}*-info
%doc README.rst
%license LICENSE

%changelog
* Mon Jul 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.0
  * Harmonize gast.dump behavior across versions, following py3.13 behavior
- from version 0.5.5
  * Provide a bug and security bug section in the README
  * Upgrade to py3.13 support
  * Slightly speedup gast node creation
  * Document ExceptHandler.name change
  * Optimize node constructors
  * Update unparser for py 3.12 and setup minimal testing
  * Reflect AST changes to README
  * Support py 3.12 type parameters
  * Update CI configuration for python 3.12 (and 2.7!)
  * Support Type aliases from Python 3.12
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- add comment on interdependency with pythran
* Wed Jan  3 2024 Dirk Müller <dmueller@suse.com>
- require setuptools
* Fri Oct 20 2023 Matej Cepl <mcepl@cepl.eu>
- Remove unnecessary BR on python-astunparse
* Tue Oct 10 2023 Matej Cepl <mcepl@cepl.eu>
- Once more on the breach! Update to 0.5.4 (see changes below).
* Wed May 17 2023 Dirk Müller <dmueller@suse.com>
- go back to 0.5.3
* Sun May 14 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.4:
  * Support TryStar from python 3.11
  * Support match statement from python 3.10
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Jan 20 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.5.3:
  + Support gast.unparse.
- Changes from version 0.5.2:
  + Test field count more accurately.
- Changes from verison 0.5.1:
  + Support NamedExpr.
  + Cleanup and optimize the way gast builds its AST.
- Changes from version 0.5.0:
  + Support AST change for 3.10.
* Mon May 24 2021 pgajdos@suse.com
- %%check: use %%pyunittest macro
* Wed Aug 26 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.0:
  * Support Python 3.9
* Mon Apr  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.3.3
  * Fix conversion of complex literals
  * Fix Ellipsis support
  * Fix conversion of arguments nodes in Python 3.8
  * Use an immutable instead of a dict to store initial table
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.0:
  * support python 3.8
* Mon Jul 29 2019 Christian Goll <cgoll@suse.com>
- inital commit of gast created with py2pack version 0.2.2
